@@ -1,4 +1,4 @@
-# Copyright (c) 2020 Jeff Irion and contributors
+# Copyright (c) 2021 Jeff Irion and contributors
 #
 # This file is part of the adb-shell package.  It incorporates work
 # covered by the following license notice:
@@ -50,12 +50,6 @@ class DeviceAuthError(Exception):
         super(DeviceAuthError, self).__init__(message, *args)
 
 
-class InterleavedDataError(Exception):
-    """We only support command sent serially.
-
-    """
-
-
 class InvalidChecksumError(Exception):
     """Checksum of data didn't match expected checksum.
 
